@@ -2,6 +2,7 @@
 
 # 
 # Copyright (c) 2007-2008 INdT.
+# Copyright (c) 2011 Neal H. Walfield
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -23,40 +24,55 @@
 # Description : Simple RSS Reader
 # ============================================================================
 
-import dbus
 import dbus.service
+import logging
+logger = logging.getLogger(__name__)
 
-def get_lock(key):
-    try:
-        bus_name = dbus.service.BusName('org.marcoz.feedingit.lock_%s' %key,bus=dbus.SessionBus(), do_not_queue=True)
-    except:
-        bus_name = None
-    return bus_name
-    
+_update_server_object = None
+def update_server_object():
+    global _update_server_object
+    assert _update_server_object is not None, \
+        "No UpdateServerObject instantiated!"
+    return _update_server_object
 
 class UpdateServerObject(dbus.service.Object):
-    def __init__(self, app):
-        # Here the service name
-        bus_name = dbus.service.BusName('org.marcoz.feedingit',bus=dbus.SessionBus())
-        # Here the object path
-        dbus.service.Object.__init__(self, bus_name, '/org/marcoz/feedingit/update')
-        self.app = app
+    def __init__(self, bus_name):
+        """
+        Start listening for requests.
+        """
+        global _update_server_object
+        assert _update_server_object is None, \
+            "Attempt to instantiate multiple UpdateServerObject objects."
+        _update_server_object = self
+
+        dbus.service.Object.__init__(self, bus_name,
+                                     '/org/marcoz/feedingit/update')
+
+    @dbus.service.method('org.marcoz.feedingit')
+    def StopUpdate(self):
+        logger.debug("Stop update called.")
 
     @dbus.service.method('org.marcoz.feedingit')
     def UpdateAll(self):
-        self.app.automaticUpdate()
-        return "Done"
-    
-    @dbus.service.method('org.marcoz.feedingit')
-    def StopUpdate(self):
-        self.app.stopUpdate()
-        return "Done"
+        logger.debug("UpdateAll called.")
+
+    @dbus.service.method('org.marcoz.feedingit', in_signature='s')
+    def Update(self, feed):
+        logger.debug("Update(%s) called." % feed)
     
     # A signal that will be exported to dbus
     @dbus.service.signal('org.marcoz.feedingit', signature='')
     def ArticleCountUpdated(self):
         pass
 
+    # A signal that will be exported to dbus
+    @dbus.service.signal('org.marcoz.feedingit', signature='uuuuttus')
+    def UpdateProgress(self, percent_complete,
+                       feeds_downloaded, feeds_downloading, feeds_pending,
+                       bytes_downloaded, bytes_uploaded, bytes_per_second,
+                       updated_feed):
+        pass
+
     # A signal that will be exported to dbus
     @dbus.service.signal('org.marcoz.feedingit', signature='')
     def UpdateStarted(self):
@@ -65,4 +81,6 @@ class UpdateServerObject(dbus.service.Object):
     # A signal that will be exported to dbus
     @dbus.service.signal('org.marcoz.feedingit', signature='')
     def UpdateFinished(self):
-        pass
\ No newline at end of file
+        pass
+
+
